<template>
  <a-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">

        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="缺陷编码"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请输入缺陷编码"
                v-decorator="['defectCode', validatorRules.defectCode ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="缺陷名称"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请输入缺陷名称"
                v-decorator="['defectName', validatorRules.defectName ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="缺陷分类"
            >
              <j-dict-select-tag  
                :disabled="disableSubmit"
                placeholder="请输入缺陷分类"
                v-decorator="['defectCategory', validatorRules.defectCategory ]"
                dictCode="defect_category"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="描述"
            >
            <a-textarea :disabled="disableSubmit" placeholder="请输入描述" v-decorator="['descreption', validatorRules.descreption ]"/>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
  </a-modal>
</template>

<script>
import { httpAction, getAction } from '@/api/manage'
import pick from 'lodash.pick'
import { duplicateCheck } from '@/api/api'//重复校验
import JDictSelectTag from '../../../../components/dict/JDictSelectTag.vue'

export default {
  components: { JDictSelectTag },
  name: "DefectModal",
  data() {
    return {
      title: "操作",
      visible: false,
      disableSubmit: false,
      model: {},
      defectId: "", //保存缺陷id
      labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
        },

      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        defectCode: {
          rules: [
            { required: true, message: '请输入缺陷编码' },
            { validator: this.validateNum },
          ]
        },
        defectName: {
          rules: [
            { required: true, message: '请输入缺陷名称' },
            { validator: this.validateName },
          ]
        },
         defectCategory: {
          rules: [
            { required: true, message: '请选择缺陷分类' },
          ]
        },
      },
      url: {
        add: "/qms/defect/add",
        edit: "/qms/defect/edit",
      },
    }
  },
  created() {
  },
  methods: {
    add() {
      this.edit({});
    },
    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.defectId = record.id;
      this.visible = true;
      this.$nextTick(() => {
        this.form.setFieldsValue(
          pick(this.model, 'defectCode', 'defectName','defectCategory','defectStatus','descreption')
        )
      });
    },
    close() {
      this.$emit('close');
      this.visible = false;
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          let formData = Object.assign(this.model, values);
          httpAction(httpurl, formData, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },
    handleCancel() {
      this.close()
    },
    //验证 编号
    validateNum(rule, value, callback) {
      var params = {
        tableName: 'qms_defect',
        fieldName: 'defect_code',
        fieldVal: value,
        dataId: this.defectId,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("缺陷编码已存在!");
        }
      })
    },
    //验证 名称
    validateName(rule, value, callback) {
      var params = {
        tableName: 'qms_defect',
        fieldName: 'defect_name',
        fieldVal: value,
        dataId: this.defectId,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("缺陷名称已存在!");
        }
      })
    },
    // 关闭弹窗时清除表单校验
    removeValidate() {
      if (this.$refs.form) this.$refs.form.clearValidate()
    }
  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>